switch OMA_Method
    case 1 % OMA calculation based on linear fit and synthesized square wave - N. Swenson
        % The OMA of the synthesized square wave is computed per Clause 52.9.5
        ant=4; mem=40; %These parameters can be varied to improve linear fit
        X=zeros(ant+mem+1,PtrnLength); %Size data matrix for linear fit
        Y=zeros(OverSampleRate,PtrnLength); %Size observation matrix for linear fit
        for ind=1:ant+mem+1
            X(ind,:)=circshift(XmitData,ind-ant-1)';%Wrap appropriately for lin fit
        end
        X=[X;ones(1,PtrnLength)]; %The all-ones row is included to compute the bias
        for ind=1:OverSampleRate
            Y(ind,:)=yout0([0:PtrnLength-1]*OverSampleRate+ind)'; %Each column is one bit period
        end
        Qmat=Y*X'*(X*X')^(-1); %Coefficient matrix resulting from linear fit. Each column (except
        %the last) is one bit period of the pulse response.  The last column is the bias.
        SqWvPer=16; %Must be even. Period of the square wave used to compute the OMA
        SqWv=[zeros(SqWvPer/2,1);ones(SqWvPer/2,1)]; %One period of square wave (column)
        X=zeros(ant+mem+1,SqWvPer); %Size data matrix for synthesis
        for ind=1:ant+mem+1
            X(ind,:)=circshift(SqWv,ind-ant-1)'; %Wrap appropriately for synthesis
        end
        X=[X;ones(1,SqWvPer)]; %Include the bias
        Y=Qmat*X;Y=Y(:); %Synthesize the modulated square wave, put into one column
        avgpos=[.4*SqWvPer/2*OverSampleRate:.6*SqWvPer/2*OverSampleRate]; %samples to average over
        SteadyZeroPower=mean(Y(round(avgpos),:)); %Average over middle 20% of "zero" run
        %Average over middle 20% of "one" run, compute OMA
        MeasuredOMA=mean(Y(round(SqWvPer/2*OverSampleRate+avgpos),:))-SteadyZeroPower;
    case 2 % OMA calculation based on spectral analysis - P. Dawe
        MeasuredSpectrum=abs(fft(yout0));
        MeasuredMean=MeasuredSpectrum(1)/TotLen;
        % Find the "perfect" pattern, after NRZ encoding
        TheoryWaveform=[];
        for k=1:length(XmitData)
            TheoryWaveform(OverSampleRate*(k-1)+1:OverSampleRate*k,1)=XmitData(k);
        end % k
        % Find its spectrum
        TheorySpectrum=abs(fft(TheoryWaveform));
        % Bessel filter
        y=2.114*j*Fgrid/7.5;
        H_Bessel=abs(105./(105+105*y+45*y.^2+10*y.^3+y.^4));
        H_Bessel=fftshift(H_Bessel);
        TheorySpectrumF=abs(TheorySpectrum.*H_Bessel);
        % Spectra are rough, so do some smoothing.  First cut out the DC component
        MeasuredSpectrumx=MeasuredSpectrum(2:end);
        TheorySpectrumFx=TheorySpectrumF(2:end);
        % Smoothing (temporarily rearrage so lowest frequency is in the middle)
        Swindow=1+2*round(PtrnLength/102);      % e.g. 11 (odd number)
        Svector=ones(Swindow,1)/Swindow;
        MeasSpectxS=filter(Svector,1,circshift(MeasuredSpectrumx,TotLen/2));
        TheorySpectFxS=filter(Svector,1,circshift(TheorySpectrumFx,TotLen/2));
        MeasSpectxS=circshift(MeasSpectxS,-(Swindow-1)/2);
        TheorySpectFxS=circshift(TheorySpectFxS,-(Swindow-1)/2);
        Swindow=1+2*round(PtrnLength/170);      % e.g. 7.  Smooth again
        Svector=ones(Swindow,1)/Swindow;
        MeasSpectxS=filter(Svector,1,MeasSpectxS);
        TheorySpectFxS=filter(Svector,1,TheorySpectFxS);
        MeasSpectxS=circshift(MeasSpectxS,-(Swindow-1)/2);
        TheorySpectFxS=circshift(TheorySpectFxS,-(Swindow-1)/2);
        % Rearrange so lowest frequency is at the beginning again
        MeasSpectxS=circshift(MeasSpectxS,-TotLen/2);
        TheorySpectFxS=circshift(TheorySpectFxS,-TotLen/2);
        indexLowF=round(PtrnLength/22);       % Line rate/(11+11)
        indexHighF=round(PtrnLength/8);       % Line rate/(4+4)
        % WAS Look for max up to half the line rate - usually max would be very near DC
        % Should experiment with upper limit below; now using low freq band only.
        %WAS% MeasuredOMA=max(MeasuredSpectrumS(2:256)./TheorySpectrumFS(2:256));
        % '64' below should be function of OverSampleRate
        MeasuredOMA=mean(MeasSpectxS(indexLowF:indexHighF)./TheorySpectFxS(indexLowF:indexHighF));
        % Find the expected mean considering that pattern may not be balanced
        DataMean=sum(XmitData)/length(XmitData);
        SteadyZeroPower=MeasuredMean-MeasuredOMA*DataMean;
        % Now want to offset this for best equalising performance with DCD
    case 3 % - P. Pepeljugoski
        % documentation is in the file top_base.m
        % needs the function zero_crossings.m
        % both functions need to be on the matlab path
        % P is the top line, and N is the base line
        [P,N]=top_base(yout0-mean(yout0),OverSampleRate,5);
        MeasuredOMA=abs(P-N);
        SteadyZeroPower=mean(yout0)-MeasuredOMA/2;
end